@@ -10,7 +10,7 @@ from func_timeout import func_timeout, FunctionTimedOut
 class Util(object):
     def __init__(self, sn):
         self.is_win = 'window' in platform.system().lower()
-        self.is_wsl = 'Linux' in platform.system() and 'Microsoft' in platform.release()  # 判断当前是不是WSL环境
+        self.is_wsl = 'linux' in platform.system().lower() and 'microsoft' in platform.release().lower()  # 判断当前是不是WSL环境
         self.is_py2 = sys.version_info < (3, 0)
         self.sn = sn
         self.debug = False
@@ -84,7 +84,16 @@ class Util(object):
             print('执行命令超时 {}s: {}'.format(timeout, arg))
 
     def adb(self, arg, timeout=30, encoding='utf-8'):
-        arg = 'adb -s {} {}'.format(self.sn, arg)
+        adb = 'adb'
+        if self.is_wsl:  # 适配 wsl2 中使用 win10 中的adb情况
+            arg = 'whereis adb'  # 获取 adb 的 path
+            out = Util.cmd(arg)
+            if 'adb:' in out:
+                out = out.replace('adb:', '').strip().split(' /')[1]  # 使用第一个 path
+                if 'adb' in out:
+                    adb = '"{}"'.format(out)  # 防止有空格，加上双引号
+
+        arg = '{} -s {} {}'.format(adb, self.sn, arg)
         return self.cmd(arg, timeout, encoding=encoding)
 
     def shell(self, arg, timeout=30, encoding='utf-8'):
